@@ -1,6 +1,6 @@
 package Proc::tored::Types;
 # ABSTRACT: Type constraints used by Proc::tored
-$Proc::tored::Types::VERSION = '0.10';
+$Proc::tored::Types::VERSION = '0.11';
 use strict;
 use warnings;
 use Types::Standard -types;
@@ -13,9 +13,9 @@ use Type::Library -base,
   );
 
 
-declare NonEmptyStr, as Str, where { $_ =~ /\S/ };
+declare NonEmptyStr, as Str, where { $_ =~ /\S/sm };
 declare Dir, as NonEmptyStr, where { -d $_ && -w $_ };
-declare SignalList, as ArrayRef[Str], where { @$_ || $^O ne 'MSWin32' };
+declare SignalList, as ArrayRef[Str], where { @$_ == 0 || $^O ne 'MSWin32' };
 
 1;
 
@@ -31,7 +31,7 @@ Proc::tored::Types - Type constraints used by Proc::tored
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 TYPES
 
